@@ -4,10 +4,7 @@ use namespace::autoclean;
 
 with 'Message::Passing::Role::Filter';
 
-sub filter {
-    my ($self, $message) = @_;
-    $message;
-}
+sub filter { $_[1] }
 
 __PACKAGE__->meta->make_immutable;
 1;
